@@ -1,7 +1,8 @@
 use anyhow::{anyhow, Result as AnyResult};
 use indicatif::ParallelProgressIterator;
 use log::{debug, error, info};
-use mpl_token_metadata::state::{Key, Metadata};
+use metaboss_lib::decode::decode_master_edition_from_mint;
+use mpl_token_metadata::state::{Key, Metadata, TokenStandard, UseMethod};
 use rayon::prelude::*;
 use retry::{delay::Exponential, retry};
 use serde::Serialize;
@@ -24,11 +25,24 @@ pub struct JSONCreator {
     pub share: u8,
 }
 
+#[derive(Debug, Serialize)]
+pub struct JSONCollection {
+    pub verified: bool,
+    pub key: String,
+}
+
+#[derive(Debug, Serialize)]
+pub struct JSONUses {
+    pub use_method: String,
+    pub remaining: u64,
+    pub total: u64,
+}
+
 pub fn decode_metadata_all(
     client: &RpcClient,
-    json_file: &String,
+    json_file: &str,
     full: bool,
-    output: &String,
+    output: &str,
 ) -> AnyResult<()> {
     let file = File::open(json_file)?;
     let mint_accounts: Vec<String> = serde_json::from_reader(file)?;
@@ -103,7 +117,6 @@ pub fn decode_metadata_all(
                         "Failed to write JSON file for mint account: {}, error: {}",
                         mint_account, err
                     );
-                    return;
                 }
             }
         });
@@ -111,13 +124,20 @@ pub fn decode_metadata_all(
     Ok(())
 }
 
+pub fn decode_master_edition(client: &RpcClient, mint_account: &str) -> AnyResult<()> {
+    let master_edition = decode_master_edition_from_mint(client, mint_account)?;
+    println!("{:?}", master_edition);
+
+    Ok(())
+}
+
 pub fn decode_metadata(
     client: &RpcClient,
     account: Option<&String>,
     full: bool,
     list_path: Option<&String>,
     raw: bool,
-    output: &String,
+    output: &str,
 ) -> AnyResult<()> {
     // Explicitly warn the user if they provide incorrect options combinations
     if !is_only_one_option(&account, &list_path) {
@@ -132,12 +152,12 @@ pub fn decode_metadata(
             println!("{:?}", data);
             return Ok(());
         }
-        let metadata = decode(client, &mint_account)?;
+        let metadata = decode(client, mint_account)?;
         let json_metadata = decode_to_json(metadata, full)?;
         let mut file = File::create(format!("{}/{}.json", output, mint_account))?;
         serde_json::to_writer(&mut file, &json_metadata)?;
     } else if let Some(list_path) = list_path {
-        decode_metadata_all(client, &list_path, full, output)?;
+        decode_metadata_all(client, list_path, full, output)?;
     } else {
         return Err(anyhow!(
             "Please specify either a mint account or a list of mint accounts, but not both."
@@ -147,10 +167,10 @@ pub fn decode_metadata(
     Ok(())
 }
 
-pub fn decode_raw(client: &RpcClient, mint_account: &String) -> Result<Vec<u8>, DecodeError> {
-    let pubkey = match Pubkey::from_str(&mint_account) {
+pub fn decode_raw(client: &RpcClient, mint_account: &str) -> Result<Vec<u8>, DecodeError> {
+    let pubkey = match Pubkey::from_str(mint_account) {
         Ok(pubkey) => pubkey,
-        Err(_) => return Err(DecodeError::PubkeyParseFailed(mint_account.clone())),
+        Err(_) => return Err(DecodeError::PubkeyParseFailed(mint_account.to_string())),
     };
     let metadata_pda = get_metadata_pda(pubkey);
 
@@ -166,10 +186,10 @@ pub fn decode_raw(client: &RpcClient, mint_account: &String) -> Result<Vec<u8>,
     Ok(account_data)
 }
 
-pub fn decode(client: &RpcClient, mint_account: &String) -> Result<Metadata, DecodeError> {
-    let pubkey = match Pubkey::from_str(&mint_account) {
+pub fn decode(client: &RpcClient, mint_account: &str) -> Result<Metadata, DecodeError> {
+    let pubkey = match Pubkey::from_str(mint_account) {
         Ok(pubkey) => pubkey,
-        Err(_) => return Err(DecodeError::PubkeyParseFailed(mint_account.clone())),
+        Err(_) => return Err(DecodeError::PubkeyParseFailed(mint_account.to_string())),
     };
     let metadata_pda = get_metadata_pda(pubkey);
 
@@ -206,10 +226,10 @@ fn decode_to_json(metadata: Metadata, full: bool) -> AnyResult<Value> {
     }
 
     let data_json = json!({
-        "name": metadata.data.name.to_string().trim_matches(char::from(0)),
-        "symbol": metadata.data.symbol.to_string().trim_matches(char::from(0)),
+        "name": metadata.data.name.trim_matches(char::from(0)),
+        "symbol": metadata.data.symbol.trim_matches(char::from(0)),
         "seller_fee_basis_points": metadata.data.seller_fee_basis_points,
-        "uri": metadata.data.uri.to_string().trim_matches(char::from(0)),
+        "uri": metadata.data.uri.trim_matches(char::from(0)),
         "creators": creators,
     });
 
@@ -217,6 +237,28 @@ fn decode_to_json(metadata: Metadata, full: bool) -> AnyResult<Value> {
         return Ok(data_json);
     }
 
+    let mut token_standard: Option<String> = None;
+    if let Some(ts) = metadata.token_standard {
+        token_standard = Some(parse_token_standard(ts))
+    }
+
+    let mut collection: Option<JSONCollection> = None;
+    if let Some(c) = metadata.collection {
+        collection = Some(JSONCollection {
+            verified: c.verified,
+            key: c.key.to_string(),
+        })
+    }
+
+    let mut uses: Option<JSONUses> = None;
+    if let Some(u) = metadata.uses {
+        uses = Some(JSONUses {
+            use_method: parse_use_method(u.use_method),
+            remaining: u.remaining,
+            total: u.total,
+        })
+    }
+
     let json_metadata = json!({
         "key": parse_key(metadata.key),
         "update_authority": metadata.update_authority.to_string(),
@@ -225,6 +267,9 @@ fn decode_to_json(metadata: Metadata, full: bool) -> AnyResult<Value> {
         "primary_sale_happened": metadata.primary_sale_happened,
         "is_mutable": metadata.is_mutable,
         "edition_nonce": metadata.edition_nonce,
+        "token_standard": token_standard,
+        "collection": collection,
+        "uses": uses,
     });
     Ok(json_metadata)
 }
@@ -258,3 +303,20 @@ fn parse_key(key: Key) -> String {
         Key::CollectionAuthorityRecord => String::from("CollectionAuthorityRecord"),
     }
 }
+
+fn parse_token_standard(token_standard: TokenStandard) -> String {
+    match token_standard {
+        TokenStandard::NonFungible => String::from("NonFungible"),
+        TokenStandard::FungibleAsset => String::from("FungibleAsset"),
+        TokenStandard::Fungible => String::from("Fungible"),
+        TokenStandard::NonFungibleEdition => String::from("NonFungibleEdition"),
+    }
+}
+
+fn parse_use_method(use_method: UseMethod) -> String {
+    match use_method {
+        UseMethod::Burn => String::from("Burn"),
+        UseMethod::Single => String::from("Single"),
+        UseMethod::Multiple => String::from("Multiple"),
+    }
+}
