@@ -2,23 +2,109 @@ use anyhow::Result;
 use solana_client::rpc_client::RpcClient;
 
 use crate::burn::burn_one;
-use crate::collections::{approve_delegate, revoke_delegate};
-use crate::decode::decode_metadata;
+use crate::collections::{
+    approve_delegate, revoke_delegate, set_and_verify_nft_collection, unverify_nft_collection,
+    verify_nft_collection,
+};
+use crate::decode::{decode_master_edition, decode_metadata};
 use crate::derive::{get_cmv2_pda, get_edition_pda, get_generic_pda, get_metadata_pda};
-use crate::mint::{mint_list, mint_one};
+use crate::find::find_missing_editions_process;
+use crate::mint::{mint_editions, mint_list, mint_missing_editions, mint_one};
 use crate::opt::*;
 use crate::sign::{sign_all, sign_one};
 use crate::snapshot::{snapshot_cm_accounts, snapshot_holders, snapshot_mints};
 use crate::update_metadata::*;
+use crate::uses::{approve_use_delegate, revoke_use_delegate, utilize_nft};
 use crate::withdraw::{withdraw, WithdrawArgs};
 
+pub fn process_uses(client: &RpcClient, commands: UsesSubcommands) -> Result<()> {
+    match commands {
+        UsesSubcommands::ApproveAuthority {
+            keypair,
+            delegate_use_authority,
+            mint_nft,
+            token_account_nft,
+            burner_program_id,
+            number_of_uses,
+        } => approve_use_delegate(
+            client,
+            keypair,
+            mint_nft,
+            delegate_use_authority,
+            token_account_nft,
+            burner_program_id,
+            number_of_uses,
+        ),
+
+        UsesSubcommands::RevokeAuthority {
+            delegate_use_authority,
+            keypair,
+            mint_nft,
+            token_account_nft,
+        } => revoke_use_delegate(
+            client,
+            keypair,
+            mint_nft,
+            delegate_use_authority,
+            token_account_nft,
+        ),
+
+        UsesSubcommands::Utilize {
+            burner_program_id,
+            is_delegate,
+            keypair,
+            mint_nft,
+            holder_nft,
+            token_account_nft,
+        } => utilize_nft(
+            client,
+            keypair,
+            mint_nft,
+            holder_nft,
+            token_account_nft,
+            burner_program_id,
+            is_delegate,
+        ),
+    }
+}
+
 pub fn process_collections(client: &RpcClient, commands: CollectionsSubcommands) -> Result<()> {
     match commands {
+        CollectionsSubcommands::VerifyCollection {
+            keypair,
+            collection_mint,
+            nft_mint,
+            is_delegate,
+        } => verify_nft_collection(client, keypair, nft_mint, collection_mint, is_delegate),
+
+        CollectionsSubcommands::UnverifyCollection {
+            keypair,
+            collection_mint,
+            is_delegate,
+            nft_mint,
+        } => unverify_nft_collection(client, keypair, nft_mint, collection_mint, is_delegate),
+
+        CollectionsSubcommands::SetAndVerifyCollection {
+            keypair,
+            nft_mint,
+            update_authority_nft,
+            collection_mint,
+            is_delegate,
+        } => set_and_verify_nft_collection(
+            client,
+            keypair,
+            nft_mint,
+            collection_mint,
+            update_authority_nft,
+            is_delegate,
+        ),
+
         CollectionsSubcommands::ApproveAuthority {
             keypair,
             collection_mint,
             delegate_authority,
         } => approve_delegate(client, keypair, collection_mint, delegate_authority),
+
         CollectionsSubcommands::RevokeAuthority {
             keypair,
             collection_mint,
@@ -49,6 +135,7 @@ pub fn process_decode(client: &RpcClient, commands: DecodeSubcommands) -> Result
             raw,
             output,
         )?,
+        DecodeSubcommands::Master { account } => decode_master_edition(client, &account)?,
     }
     Ok(())
 }
@@ -62,6 +149,14 @@ pub fn process_derive(commands: DeriveSubcommands) {
     }
 }
 
+pub fn process_find(client: &RpcClient, commands: FindSubcommands) -> Result<()> {
+    match commands {
+        FindSubcommands::MissingEditions { account } => {
+            find_missing_editions_process(client, &account)
+        }
+    }
+}
+
 pub fn process_mint(client: &RpcClient, commands: MintSubcommands) -> Result<()> {
     match commands {
         MintSubcommands::One {
@@ -71,17 +166,37 @@ pub fn process_mint(client: &RpcClient, commands: MintSubcommands) -> Result<()>
             external_metadata_uri,
             immutable,
             primary_sale_happened,
+            max_editions,
             sign,
         } => mint_one(
-            &client,
-            &keypair,
+            client,
+            keypair,
             &receiver,
             nft_data_file,
             external_metadata_uri.as_ref(),
             immutable,
             primary_sale_happened,
+            max_editions,
             sign,
+        )
+        .map(|_| ()),
+        MintSubcommands::Editions {
+            keypair,
+            account,
+            receiver,
+            next_editions,
+            specific_editions,
+        } => mint_editions(
+            client,
+            keypair,
+            account,
+            &receiver,
+            next_editions,
+            specific_editions,
         ),
+        MintSubcommands::MissingEditions { keypair, account } => {
+            mint_missing_editions(client, &keypair, &account)
+        }
         MintSubcommands::List {
             keypair,
             receiver,
@@ -90,8 +205,9 @@ pub fn process_mint(client: &RpcClient, commands: MintSubcommands) -> Result<()>
             immutable,
             primary_sale_happened,
             sign,
+            track,
         } => mint_list(
-            &client,
+            client,
             keypair,
             receiver,
             nft_data_dir,
@@ -99,6 +215,7 @@ pub fn process_mint(client: &RpcClient, commands: MintSubcommands) -> Result<()>
             immutable,
             primary_sale_happened,
             sign,
+            track,
         ),
     }
 }
@@ -106,50 +223,50 @@ pub fn process_mint(client: &RpcClient, commands: MintSubcommands) -> Result<()>
 pub fn process_set(client: &RpcClient, commands: SetSubcommands) -> Result<()> {
     match commands {
         SetSubcommands::PrimarySaleHappened { keypair, account } => {
-            set_primary_sale_happened(&client, &keypair, &account)
+            set_primary_sale_happened(client, keypair, &account)
         }
         SetSubcommands::UpdateAuthority {
             keypair,
             account,
             new_update_authority,
-        } => set_update_authority(&client, &keypair, &account, &new_update_authority),
+            keypair_payer,
+        } => set_update_authority(
+            client,
+            keypair,
+            &account,
+            &new_update_authority,
+            keypair_payer,
+        ),
         SetSubcommands::UpdateAuthorityAll {
             keypair,
             mint_accounts_file,
             new_update_authority,
+            keypair_payer,
         } => set_update_authority_all(
-            &client,
-            &keypair,
+            client,
+            keypair,
             &mint_accounts_file,
             &new_update_authority,
+            keypair_payer,
         ),
-        SetSubcommands::Immutable { keypair, account } => {
-            set_immutable(&client, &keypair, &account)
-        }
+        SetSubcommands::Immutable { keypair, account } => set_immutable(client, keypair, &account),
         SetSubcommands::ImmutableAll {
             keypair,
             mint_accounts_file,
-        } => set_immutable_all(&client, &keypair, &mint_accounts_file),
+        } => set_immutable_all(client, keypair, &mint_accounts_file),
     }
 }
 
 pub fn process_sign(client: &RpcClient, commands: SignSubcommands) -> Result<()> {
     match commands {
-        SignSubcommands::One { keypair, account } => sign_one(&client, keypair, account),
+        SignSubcommands::One { keypair, account } => sign_one(client, keypair, account),
         SignSubcommands::All {
             keypair,
             creator,
             position,
             v2,
             mint_accounts_file,
-        } => sign_all(
-            &client,
-            &keypair,
-            &creator,
-            position,
-            v2,
-            mint_accounts_file,
-        ),
+        } => sign_all(client, keypair, &creator, position, v2, mint_accounts_file),
     }
 }
 
@@ -163,7 +280,7 @@ pub fn process_snapshot(client: &RpcClient, commands: SnapshotSubcommands) -> Re
             v2,
             output,
         } => snapshot_holders(
-            &client,
+            client,
             &update_authority,
             &creator,
             position,
@@ -174,14 +291,14 @@ pub fn process_snapshot(client: &RpcClient, commands: SnapshotSubcommands) -> Re
         SnapshotSubcommands::CMAccounts {
             update_authority,
             output,
-        } => snapshot_cm_accounts(&client, &update_authority, &output),
+        } => snapshot_cm_accounts(client, &update_authority, &output),
         SnapshotSubcommands::Mints {
             creator,
             position,
             update_authority,
             v2,
             output,
-        } => snapshot_mints(&client, &creator, position, update_authority, v2, output),
+        } => snapshot_mints(client, &creator, position, update_authority, v2, output),
     }
 }
 
@@ -191,33 +308,33 @@ pub fn process_update(client: &RpcClient, commands: UpdateSubcommands) -> Result
             keypair,
             account,
             new_name,
-        } => update_name_one(&client, &keypair, &account, &new_name),
+        } => update_name_one(client, keypair, &account, &new_name),
         UpdateSubcommands::Symbol {
             keypair,
             account,
             new_symbol,
-        } => update_symbol_one(&client, &keypair, &account, &new_symbol),
+        } => update_symbol_one(client, keypair, &account, &new_symbol),
         UpdateSubcommands::Creators {
             keypair,
             account,
             new_creators,
             append,
-        } => update_creator_by_position(&client, &keypair, &account, &new_creators, append),
+        } => update_creator_by_position(client, keypair, &account, &new_creators, append),
         UpdateSubcommands::Data {
             keypair,
             account,
             new_data_file,
-        } => update_data_one(&client, &keypair, &account, &new_data_file),
+        } => update_data_one(client, keypair, &account, &new_data_file),
         UpdateSubcommands::DataAll { keypair, data_dir } => {
-            update_data_all(&client, &keypair, &data_dir)
+            update_data_all(client, keypair, &data_dir)
         }
         UpdateSubcommands::Uri {
             keypair,
             account,
             new_uri,
-        } => update_uri_one(&client, &keypair, &account, &new_uri),
+        } => update_uri_one(client, keypair, &account, &new_uri),
         UpdateSubcommands::UriAll { keypair, json_file } => {
-            update_uri_all(&client, &keypair, &json_file)
+            update_uri_all(client, keypair, &json_file)
         }
     }
 }
